# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`simp_options`](#simp_options): Sets up variables that enable core SIMP capabilities or provide site configuration larger than the scope of a single module
* [`simp_options::dns`](#simp_optionsdns): Sets up DNS configuration variables
* [`simp_options::gid`](#simp_optionsgid): Provides system-wide defaults for GID settings
* [`simp_options::ldap`](#simp_optionsldap): Sets up LDAP configuration variables
* [`simp_options::ntp`](#simp_optionsntp): Sets up NTP configuration variables
* [`simp_options::ntpd`](#simp_optionsntpd): Sets up NTP configuration variables
* [`simp_options::openssl`](#simp_optionsopenssl): Sets up OpenSSL configuration variables
* [`simp_options::openssl::params`](#simp_optionsopensslparams): Sets appropriate openssl cipher suite based on whether FIPS-mode is
* [`simp_options::pki`](#simp_optionspki): Sets up global PKI configuration variables
* [`simp_options::puppet`](#simp_optionspuppet): Sets up Puppet configuration variables
* [`simp_options::rsync`](#simp_optionsrsync): Sets up ``rsync`` configuration variables
* [`simp_options::syslog`](#simp_optionssyslog): Sets up ``syslog`` configuration variables
* [`simp_options::uid`](#simp_optionsuid): Provides system-wide defaults for UID settings

## Classes

### <a name="simp_options"></a>`simp_options`

Sets up variables that enable core SIMP capabilities or provide site configuration larger than the scope of a single module

#### Parameters

The following parameters are available in the `simp_options` class:

* [`auditd`](#auditd)
* [`clamav`](#clamav)
* [`fips`](#fips)
* [`firewall`](#firewall)
* [`haveged`](#haveged)
* [`ipsec`](#ipsec)
* [`kerberos`](#kerberos)
* [`ldap`](#ldap)
* [`logrotate`](#logrotate)
* [`pam`](#pam)
* [`pki`](#pki)
* [`sssd`](#sssd)
* [`stunnel`](#stunnel)
* [`syslog`](#syslog)
* [`tcpwrappers`](#tcpwrappers)
* [`trusted_nets`](#trusted_nets)
* [`package_ensure`](#package_ensure)
* [`libkv`](#libkv)

##### <a name="auditd"></a>`auditd`

Data type: `Boolean`

Include SIMP's ``auditd`` class and add audit rules pertinent to each
application

Default value: ``false``

##### <a name="clamav"></a>`clamav`

Data type: `Boolean`

Deprecated - DO NOT USE

Default value: ``false``

##### <a name="fips"></a>`fips`

Data type: `Boolean`

Enable ``FIPS`` mode for the system

This parameter enforces strict compliance with ``FIPS-140-2``.

All core SIMP modules can support this configuration. It is important that
you know the security tradeoffs of ``FIPS-140-2`` compliance.

``FIPS`` mode disables the use of ``MD5`` and may require weaker ciphers or
key lengths than your security policies allow.

@see http://simp.readthedocs.io/en/stable/security_mapping/components/simp/cryptographic_protection/control.html SIMP - Security Control Mapping Cryptographic Protection

Default value: ``false``

##### <a name="firewall"></a>`firewall`

Data type: `Boolean`

Indicate that you want to load the native SIMP firewall management subsystem

Default value: ``false``

##### <a name="haveged"></a>`haveged`

Data type: `Boolean`

Include the ``haveged`` class to ensure adequate entropy for key
generation

@see http://simp.readthedocs.io/en/stable/getting_started_guide/Installation_Options/ISO/ISO_Build/Environment_Preparation.html?highlight=haveged SIMP - Getting Started Environment Preparation

Default value: ``false``

##### <a name="ipsec"></a>`ipsec`

Data type: `Boolean`

Include SIMP's ``ipsec`` class, ``libreswan``, and add rules pertinent to
each application

Default value: ``false``

##### <a name="kerberos"></a>`kerberos`

Data type: `Boolean`

Include the SIMP's Kerberos class, ``krb5``, and to use ``Kerberos`` in
applicable modules

Default value: ``false``

##### <a name="ldap"></a>`ldap`

Data type: `Boolean`

Encourage modules to use ``LDAP`` support where possible

Default value: ``false``

##### <a name="logrotate"></a>`logrotate`

Data type: `Boolean`

Include SIMP's ``logrotate`` class and add rules pertinent to each
application

Default value: ``false``

##### <a name="pam"></a>`pam`

Data type: `Boolean`

Include SIMP's ``pam`` class SIMP to manage ``PAM``

Default value: ``false``

##### <a name="pki"></a>`pki`

Data type: `Variant[Boolean,Enum['simp']]`

Include SIMP's ``pki`` class and use ``pki::copy`` to distribute PKI
certificates to the correct locations

* If ``false``, don't include SIMP's ``pki`` class, and don't use
  ``pki::copy``
* If ``true``,  don't include SIMP's ``pki`` class, but do use ``pki::copy``
* If ``simp``, include SIMP's ``pki`` class, and use ``pki::copy``

Default value: ``false``

##### <a name="sssd"></a>`sssd`

Data type: `Boolean`

Enable ``SSSD`` support where possible

Default value: ``false``

##### <a name="stunnel"></a>`stunnel`

Data type: `Boolean`

Include SIMP's ``stunnel`` class and use it to secure server-to-server
communications in applicable modules

Default value: ``false``

##### <a name="syslog"></a>`syslog`

Data type: `Boolean`

Include SIMP's ``rsyslog`` class and configure RSyslog application hooks

Default value: ``false``

##### <a name="tcpwrappers"></a>`tcpwrappers`

Data type: `Boolean`

Whether to include SIMP's ``tcpwrappers`` class and use
``tcpwrappers::allow`` to permit the application to the subnets in
``$simp_options::trusted_nets``

Default value: ``false``

##### <a name="trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Subnets to permit, in ``CIDR`` notation

* If you need this to be more (or less) restrictive for a given class, you
  can override it for the specific class via that class' parameters.

Default value: `['127.0.0.1', '::1']`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

The default ensure parameter for packages

* Can be either ``latest`` or ``installed``

Default value: `'latest'`

##### <a name="libkv"></a>`libkv`

Data type: `Boolean`

Enable the libkv backend for some functions

Default value: ``false``

### <a name="simp_optionsdns"></a>`simp_options::dns`

Sets up DNS configuration variables

#### Parameters

The following parameters are available in the `simp_options::dns` class:

* [`search`](#search)
* [`servers`](#servers)

##### <a name="search"></a>`search`

Data type: `Array[String]`

The DNS search list. Remember to put these in the appropriate
order for your environment.

Default value: `[]`

##### <a name="servers"></a>`servers`

Data type: `Array[Simplib::Host]`

The list of DNS servers for the managed hosts.

If the first entry of this list is set to ``127.0.0.1``, then all clients
will configure themselves as caching DNS servers pointing to the other
entries in the list.

---------------------------------------------------------------------------
If you are using the SIMP ``resolv`` module, and the system is a DNS server
using the SIMP ``named`` module but you wish to have your node point to a
different DNS server for primary DNS resolution, then you MUST set
``resolv::named_server`` to ``true`` via Hiera.

This will get around the convenience logic that was put in place to handle
the caching entries and will not attempt to convert your system to a
caching DNS server.

---------------------------------------------------------------------------

Default value: `[]`

### <a name="simp_optionsgid"></a>`simp_options::gid`

Provides system-wide defaults for GID settings

#### Parameters

The following parameters are available in the `simp_options::gid` class:

* [`min`](#min)
* [`max`](#max)

##### <a name="min"></a>`min`

Data type: `Integer[0]`

The lowest allowed regular user GID for the system

Default value: `pick(fact('login_defs.gid_min'), 1000)`

##### <a name="max"></a>`max`

Data type: `Optional[Integer[1]]`

The highest allowed regular user GID for the system

* If not defined, applications should simply do what makes sense for them
  internally

Default value: `fact('login_defs.gid_max')`

### <a name="simp_optionsldap"></a>`simp_options::ldap`

Some parameters have default values in `simp_options/data/ldap.yaml`, all
others **must** have a value specified via Hiera or your ENC.

#### Parameters

The following parameters are available in the `simp_options::ldap` class:

* [`base_dn`](#base_dn)
* [`bind_dn`](#bind_dn)
* [`bind_pw`](#bind_pw)
* [`bind_hash`](#bind_hash)
* [`sync_dn`](#sync_dn)
* [`sync_pw`](#sync_pw)
* [`sync_hash`](#sync_hash)
* [`root_dn`](#root_dn)
* [`master`](#master)
* [`uri`](#uri)

##### <a name="base_dn"></a>`base_dn`

Data type: `String`

The Base Distinguished Name of the LDAP server

Default value: `simplib::ldap::domain_to_dn()`

##### <a name="bind_dn"></a>`bind_dn`

Data type: `String`

The LDAP Bind Distinguished Name

Default value: `"cn=hostAuth,ou=Hosts,${base_dn}"`

##### <a name="bind_pw"></a>`bind_pw`

Data type: `String`

The LDAP Bind password

##### <a name="bind_hash"></a>`bind_hash`

Data type: `String`

The salted LDAP Bind password hash

##### <a name="sync_dn"></a>`sync_dn`

Data type: `String`

The LDAP Sync Distinguished Name

Default value: `"cn=LDAPSync,ou=Hosts,${base_dn}"`

##### <a name="sync_pw"></a>`sync_pw`

Data type: `String`

The LDAP Sync password

##### <a name="sync_hash"></a>`sync_hash`

Data type: `String`

The LDAP Sync password hash

##### <a name="root_dn"></a>`root_dn`

Data type: `String`

The LDAP Root Distinguished Name

Default value: `"cn=LDAPAdmin,ou=People,${base_dn}"`

##### <a name="master"></a>`master`

Data type: `Simplib::URI`

The LDAP master in URI form (ldap://server)

Default value: `$simp_options::puppet::server`

##### <a name="uri"></a>`uri`

Data type: `Array[Simplib::URI]`

The list of OpenLDAP servers in URI form (ldap://server)

Default value: `$master`

### <a name="simp_optionsntp"></a>`simp_options::ntp`

@example A hash of servers
  {
    'ntp1.example.com' => [
      'minpoll 3',
      'maxpoll 6',
    ],
    'ntp2.example.com' => [
      'iburst',
      'minpoll 4',
      'maxpoll 8',
    ]
  }

#### Examples

##### An array of servers

```puppet
[
  'ntp1.example.com',
  'ntp2.example.com',
]
```

#### Parameters

The following parameters are available in the `simp_options::ntp` class:

* [`servers`](#servers)

##### <a name="servers"></a>`servers`

Data type: `Variant[Hash[Simplib::Host, Array[String[1]]], Array[Simplib::Host]]`

The NTP time servers for the network and, optionally,
configuration for the daemons that communicate with them.

A consistent time source is critical to your systems' security. **DO NOT**
run multiple production systems using individual hardware clocks!

Default value: `[]`

### <a name="simp_optionsntpd"></a>`simp_options::ntpd`

Sets up NTP configuration variables

#### Parameters

The following parameters are available in the `simp_options::ntpd` class:

* [`servers`](#servers)

##### <a name="servers"></a>`servers`

Data type: `Array[Simplib::Host]`

**DEPRECATED** Use simp_options::ntp instead.
The list of NTP time servers for the network.
A consistent time source is critical to your systems' security. **DO NOT**
run multiple production systems using individual hardware clocks!

Default value: `[]`

### <a name="simp_optionsopenssl"></a>`simp_options::openssl`

Sets up OpenSSL configuration variables

* **See also**
  * https://wiki.openssl.org/index.php/Command_Line_Utilities#ciphers
    * OpenSSL Ciphers Command

#### Parameters

The following parameters are available in the `simp_options::openssl` class:

* [`cipher_suite`](#cipher_suite)

##### <a name="cipher_suite"></a>`cipher_suite`

Data type: `Array[String]`

The default ciphers to use in openssl.

Default value: `$::simp_options::openssl::params::cipher_suite`

### <a name="simp_optionsopensslparams"></a>`simp_options::openssl::params`

desired or the system is already in FIPS mode.

### <a name="simp_optionspki"></a>`simp_options::pki`

Sets up global PKI configuration variables

#### Parameters

The following parameters are available in the `simp_options::pki` class:

* [`source`](#source)

##### <a name="source"></a>`source`

Data type: `Stdlib::Absolutepath`

The source location for PKI certificates.  This is the source
directory for pki::copy.

Default value: `'/etc/pki/simp/x509'`

### <a name="simp_optionspuppet"></a>`simp_options::puppet`

Sets up Puppet configuration variables

#### Parameters

The following parameters are available in the `simp_options::puppet` class:

* [`server`](#server)
* [`ca`](#ca)
* [`ca_port`](#ca_port)
* [`server_distribution`](#server_distribution)

##### <a name="server"></a>`server`

Data type: `Optional[Simplib::Host]`

The ``Hostname`` or ``FQDN`` of the Puppet server

Default value: ``undef``

##### <a name="ca"></a>`ca`

Data type: `Optional[Simplib::Host]`

The Puppet Certificate Authority

Default value: ``undef``

##### <a name="ca_port"></a>`ca_port`

Data type: `Simplib::Port`

The port on which the Puppet Certificate Authority will listen

Default value: `$server_distribution`

##### <a name="server_distribution"></a>`server_distribution`

Data type: `Simplib::Serverdistribution`

The server distribution being used, PC1 or PE.

Default value: `(`

### <a name="simp_optionsrsync"></a>`simp_options::rsync`

Sets up ``rsync`` configuration variables

#### Parameters

The following parameters are available in the `simp_options::rsync` class:

* [`server`](#server)
* [`timeout`](#timeout)

##### <a name="server"></a>`server`

Data type: `Simplib::Host`

Server to use for the simp::rsync_server class.

This class is used by several SIMP modules to efficiently synchronize large
data files using ``rsync`` over ``stunnel``.

The **default value** of ``127.0.0.1`` is appropriate for rsync over stunnel.

Default value: `'127.0.0.1'`

##### <a name="timeout"></a>`timeout`

Data type: `Integer`

rsync connection timeout in **seconds**

Default value: `1`

### <a name="simp_optionssyslog"></a>`simp_options::syslog`

Sets up ``syslog`` configuration variables

#### Parameters

The following parameters are available in the `simp_options::syslog` class:

* [`log_servers`](#log_servers)
* [`failover_log_servers`](#failover_log_servers)

##### <a name="log_servers"></a>`log_servers`

Data type: `Array[Simplib::Host]`

The log servers to receive forwarded logs

Default value: `[]`

##### <a name="failover_log_servers"></a>`failover_log_servers`

Data type: `Array[Simplib::Host]`

Failover log servers in case your log servers fail

Default value: `[]`

### <a name="simp_optionsuid"></a>`simp_options::uid`

Provides system-wide defaults for UID settings

#### Parameters

The following parameters are available in the `simp_options::uid` class:

* [`min`](#min)
* [`max`](#max)

##### <a name="min"></a>`min`

Data type: `Integer[0]`

The lowest allowed regular user UID for the system

Default value: `pick(fact('login_defs.uid_min'), 1000)`

##### <a name="max"></a>`max`

Data type: `Optional[Integer[1]]`

The highest allowed regular user UID for the system

* If not defined, applications should simply do what makes sense for them
  internally

Default value: `fact('login_defs.uid_max')`

